from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Foundation.Collections
import win32more.Windows.Gaming.Input
import win32more.Windows.Gaming.Input.Custom
import win32more.Windows.Gaming.Input.Preview
import win32more.Windows.System
import win32more.Windows.Win32.System.WinRT
class DeviceCommand(Enum, Int32):
    Reset = 0
class GameControllerBatteryChargingState(Enum, Int32):
    Unknown = 0
    Inactive = 1
    Active = 2
    Error = 3
class GameControllerBatteryKind(Enum, Int32):
    Unknown = 0
    None_ = 1
    Standard = 2
    Rechargeable = 3
class GameControllerBatteryLevel(Enum, Int32):
    Unknown = 0
    Critical = 1
    Low = 2
    Medium = 3
    Full = 4
class GameControllerFirmwareCorruptReason(Enum, Int32):
    Unknown = 0
    NotCorrupt = 1
    TwoUpCorrupt = 2
    AppCorrupt = 3
    RadioCorrupt = 4
    EepromCorrupt = 5
    SafeToUpdate = 6
class GameControllerProviderInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Gaming.Input.Preview.GameControllerProviderInfo'
    @winrt_classmethod
    def GetParentProviderId(cls: win32more.Windows.Gaming.Input.Preview.IGameControllerProviderInfoStatics, provider: win32more.Windows.Gaming.Input.Custom.IGameControllerProvider) -> WinRT_String: ...
    @winrt_classmethod
    def GetProviderId(cls: win32more.Windows.Gaming.Input.Preview.IGameControllerProviderInfoStatics, provider: win32more.Windows.Gaming.Input.Custom.IGameControllerProvider) -> WinRT_String: ...
class HeadsetGeqGains(Structure):
    band1Gain: Int32
    band2Gain: Int32
    band3Gain: Int32
    band4Gain: Int32
    band5Gain: Int32
class HeadsetLevel(Enum, Int32):
    Off = 0
    Low = 1
    Medium = 2
    High = 3
class HeadsetOperation(Enum, Int32):
    Geq = 0
    BassBoostGain = 1
    SmartMute = 2
    SideTone = 3
    MuteLedBrightness = 4
    SwapMixAndVolumeDials = 5
class IGameControllerProviderInfoStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Gaming.Input.Preview.IGameControllerProviderInfoStatics'
    _iid_ = Guid('{0be1e6c5-d9bd-44ee-8362-488b2e464bfb}')
    @winrt_commethod(6)
    def GetParentProviderId(self, provider: win32more.Windows.Gaming.Input.Custom.IGameControllerProvider) -> WinRT_String: ...
    @winrt_commethod(7)
    def GetProviderId(self, provider: win32more.Windows.Gaming.Input.Custom.IGameControllerProvider) -> WinRT_String: ...
class ILegacyGipGameControllerProvider(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Gaming.Input.Preview.ILegacyGipGameControllerProvider'
    _iid_ = Guid('{2da3ed52-ffd9-43e2-825c-1d2790e04d14}')
    @winrt_commethod(6)
    def get_BatteryChargingState(self) -> win32more.Windows.Gaming.Input.Preview.GameControllerBatteryChargingState: ...
    @winrt_commethod(7)
    def get_BatteryKind(self) -> win32more.Windows.Gaming.Input.Preview.GameControllerBatteryKind: ...
    @winrt_commethod(8)
    def get_BatteryLevel(self) -> win32more.Windows.Gaming.Input.Preview.GameControllerBatteryLevel: ...
    @winrt_commethod(9)
    def GetDeviceFirmwareCorruptionState(self) -> win32more.Windows.Gaming.Input.Preview.GameControllerFirmwareCorruptReason: ...
    @winrt_commethod(10)
    def get_IsFirmwareCorrupted(self) -> Boolean: ...
    @winrt_commethod(11)
    def IsInterfaceSupported(self, interfaceId: Guid) -> Boolean: ...
    @winrt_commethod(12)
    def get_IsSyntheticDevice(self) -> Boolean: ...
    @winrt_commethod(13)
    def get_PreferredTypes(self) -> win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]: ...
    @winrt_commethod(14)
    def ExecuteCommand(self, command: win32more.Windows.Gaming.Input.Preview.DeviceCommand) -> Void: ...
    @winrt_commethod(15)
    def SetHomeLedIntensity(self, intensity: Byte) -> Void: ...
    @winrt_commethod(16)
    def GetExtendedDeviceInfo(self) -> ReceiveArray[Byte]: ...
    @winrt_commethod(17)
    def SetHeadsetOperation(self, operation: win32more.Windows.Gaming.Input.Preview.HeadsetOperation, buffer: PassArray[Byte]) -> Void: ...
    @winrt_commethod(18)
    def GetHeadsetOperation(self, operation: win32more.Windows.Gaming.Input.Preview.HeadsetOperation) -> ReceiveArray[Byte]: ...
    @winrt_commethod(19)
    def get_AppCompatVersion(self) -> UInt32: ...
    @winrt_commethod(20)
    def SetStandardControllerButtonRemapping(self, user: win32more.Windows.System.User, previous: Boolean, remapping: win32more.Windows.Foundation.Collections.IMapView[win32more.Windows.Gaming.Input.Preview.RemappingButtonCategory, win32more.Windows.Win32.System.WinRT.IInspectable]) -> Void: ...
    @winrt_commethod(21)
    def GetStandardControllerButtonRemapping(self, user: win32more.Windows.System.User, previous: Boolean) -> win32more.Windows.Foundation.Collections.IMapView[win32more.Windows.Gaming.Input.Preview.RemappingButtonCategory, win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    AppCompatVersion = property(get_AppCompatVersion, None)
    BatteryChargingState = property(get_BatteryChargingState, None)
    BatteryKind = property(get_BatteryKind, None)
    BatteryLevel = property(get_BatteryLevel, None)
    IsFirmwareCorrupted = property(get_IsFirmwareCorrupted, None)
    IsSyntheticDevice = property(get_IsSyntheticDevice, None)
    PreferredTypes = property(get_PreferredTypes, None)
class ILegacyGipGameControllerProviderStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Gaming.Input.Preview.ILegacyGipGameControllerProviderStatics'
    _iid_ = Guid('{d40dda17-b1f4-499a-874c-7095aac15291}')
    @winrt_commethod(6)
    def FromGameController(self, controller: win32more.Windows.Gaming.Input.IGameController) -> win32more.Windows.Gaming.Input.Preview.LegacyGipGameControllerProvider: ...
    @winrt_commethod(7)
    def FromGameControllerProvider(self, provider: win32more.Windows.Gaming.Input.Custom.IGameControllerProvider) -> win32more.Windows.Gaming.Input.Preview.LegacyGipGameControllerProvider: ...
    @winrt_commethod(8)
    def PairPilotToCopilot(self, user: win32more.Windows.System.User, pilotControllerProviderId: WinRT_String, copilotControllerProviderId: WinRT_String) -> Void: ...
    @winrt_commethod(9)
    def ClearPairing(self, user: win32more.Windows.System.User, controllerProviderId: WinRT_String) -> Void: ...
    @winrt_commethod(10)
    def IsPilot(self, user: win32more.Windows.System.User, controllerProviderId: WinRT_String) -> WinRT_String: ...
    @winrt_commethod(11)
    def IsCopilot(self, user: win32more.Windows.System.User, controllerProviderId: WinRT_String) -> WinRT_String: ...
class LegacyGipGameControllerProvider(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Gaming.Input.Preview.ILegacyGipGameControllerProvider
    _classid_ = 'Windows.Gaming.Input.Preview.LegacyGipGameControllerProvider'
    @winrt_mixinmethod
    def get_BatteryChargingState(self: win32more.Windows.Gaming.Input.Preview.ILegacyGipGameControllerProvider) -> win32more.Windows.Gaming.Input.Preview.GameControllerBatteryChargingState: ...
    @winrt_mixinmethod
    def get_BatteryKind(self: win32more.Windows.Gaming.Input.Preview.ILegacyGipGameControllerProvider) -> win32more.Windows.Gaming.Input.Preview.GameControllerBatteryKind: ...
    @winrt_mixinmethod
    def get_BatteryLevel(self: win32more.Windows.Gaming.Input.Preview.ILegacyGipGameControllerProvider) -> win32more.Windows.Gaming.Input.Preview.GameControllerBatteryLevel: ...
    @winrt_mixinmethod
    def GetDeviceFirmwareCorruptionState(self: win32more.Windows.Gaming.Input.Preview.ILegacyGipGameControllerProvider) -> win32more.Windows.Gaming.Input.Preview.GameControllerFirmwareCorruptReason: ...
    @winrt_mixinmethod
    def get_IsFirmwareCorrupted(self: win32more.Windows.Gaming.Input.Preview.ILegacyGipGameControllerProvider) -> Boolean: ...
    @winrt_mixinmethod
    def IsInterfaceSupported(self: win32more.Windows.Gaming.Input.Preview.ILegacyGipGameControllerProvider, interfaceId: Guid) -> Boolean: ...
    @winrt_mixinmethod
    def get_IsSyntheticDevice(self: win32more.Windows.Gaming.Input.Preview.ILegacyGipGameControllerProvider) -> Boolean: ...
    @winrt_mixinmethod
    def get_PreferredTypes(self: win32more.Windows.Gaming.Input.Preview.ILegacyGipGameControllerProvider) -> win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]: ...
    @winrt_mixinmethod
    def ExecuteCommand(self: win32more.Windows.Gaming.Input.Preview.ILegacyGipGameControllerProvider, command: win32more.Windows.Gaming.Input.Preview.DeviceCommand) -> Void: ...
    @winrt_mixinmethod
    def SetHomeLedIntensity(self: win32more.Windows.Gaming.Input.Preview.ILegacyGipGameControllerProvider, intensity: Byte) -> Void: ...
    @winrt_mixinmethod
    def GetExtendedDeviceInfo(self: win32more.Windows.Gaming.Input.Preview.ILegacyGipGameControllerProvider) -> ReceiveArray[Byte]: ...
    @winrt_mixinmethod
    def SetHeadsetOperation(self: win32more.Windows.Gaming.Input.Preview.ILegacyGipGameControllerProvider, operation: win32more.Windows.Gaming.Input.Preview.HeadsetOperation, buffer: PassArray[Byte]) -> Void: ...
    @winrt_mixinmethod
    def GetHeadsetOperation(self: win32more.Windows.Gaming.Input.Preview.ILegacyGipGameControllerProvider, operation: win32more.Windows.Gaming.Input.Preview.HeadsetOperation) -> ReceiveArray[Byte]: ...
    @winrt_mixinmethod
    def get_AppCompatVersion(self: win32more.Windows.Gaming.Input.Preview.ILegacyGipGameControllerProvider) -> UInt32: ...
    @winrt_mixinmethod
    def SetStandardControllerButtonRemapping(self: win32more.Windows.Gaming.Input.Preview.ILegacyGipGameControllerProvider, user: win32more.Windows.System.User, previous: Boolean, remapping: win32more.Windows.Foundation.Collections.IMapView[win32more.Windows.Gaming.Input.Preview.RemappingButtonCategory, win32more.Windows.Win32.System.WinRT.IInspectable]) -> Void: ...
    @winrt_mixinmethod
    def GetStandardControllerButtonRemapping(self: win32more.Windows.Gaming.Input.Preview.ILegacyGipGameControllerProvider, user: win32more.Windows.System.User, previous: Boolean) -> win32more.Windows.Foundation.Collections.IMapView[win32more.Windows.Gaming.Input.Preview.RemappingButtonCategory, win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    @winrt_classmethod
    def FromGameController(cls: win32more.Windows.Gaming.Input.Preview.ILegacyGipGameControllerProviderStatics, controller: win32more.Windows.Gaming.Input.IGameController) -> win32more.Windows.Gaming.Input.Preview.LegacyGipGameControllerProvider: ...
    @winrt_classmethod
    def FromGameControllerProvider(cls: win32more.Windows.Gaming.Input.Preview.ILegacyGipGameControllerProviderStatics, provider: win32more.Windows.Gaming.Input.Custom.IGameControllerProvider) -> win32more.Windows.Gaming.Input.Preview.LegacyGipGameControllerProvider: ...
    @winrt_classmethod
    def PairPilotToCopilot(cls: win32more.Windows.Gaming.Input.Preview.ILegacyGipGameControllerProviderStatics, user: win32more.Windows.System.User, pilotControllerProviderId: WinRT_String, copilotControllerProviderId: WinRT_String) -> Void: ...
    @winrt_classmethod
    def ClearPairing(cls: win32more.Windows.Gaming.Input.Preview.ILegacyGipGameControllerProviderStatics, user: win32more.Windows.System.User, controllerProviderId: WinRT_String) -> Void: ...
    @winrt_classmethod
    def IsPilot(cls: win32more.Windows.Gaming.Input.Preview.ILegacyGipGameControllerProviderStatics, user: win32more.Windows.System.User, controllerProviderId: WinRT_String) -> WinRT_String: ...
    @winrt_classmethod
    def IsCopilot(cls: win32more.Windows.Gaming.Input.Preview.ILegacyGipGameControllerProviderStatics, user: win32more.Windows.System.User, controllerProviderId: WinRT_String) -> WinRT_String: ...
    AppCompatVersion = property(get_AppCompatVersion, None)
    BatteryChargingState = property(get_BatteryChargingState, None)
    BatteryKind = property(get_BatteryKind, None)
    BatteryLevel = property(get_BatteryLevel, None)
    IsFirmwareCorrupted = property(get_IsFirmwareCorrupted, None)
    IsSyntheticDevice = property(get_IsSyntheticDevice, None)
    PreferredTypes = property(get_PreferredTypes, None)
class RemappingButtonCategory(Enum, Int32):
    ButtonSettings = 0
    AnalogSettings = 1
    VibrationSettings = 2
    ShareShortPress = 3
    ShareShortPressMetaData = 4
    ShareShortPressMetaDataDisplay = 5
    ShareLongPress = 6
    ShareLongPressMetaData = 7
    ShareLongPressMetaDataDisplay = 8
    ShareDoublePress = 9
    ShareDoublePressMetaData = 10
    ShareDoublePressMetaDataDisplay = 11


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.System.Com
import win32more.Windows.Win32.UI.Input.Ink
class IInkCommitRequestHandler(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{fabea3fc-b108-45b6-a9fc-8d08fa9f85cf}')
    @commethod(3)
    def OnCommitRequested(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IInkD2DRenderer(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{407fb1de-f85a-4150-97cf-b7fb274fb4f8}')
    @commethod(3)
    def Draw(self, pD2D1DeviceContext: win32more.Windows.Win32.System.Com.IUnknown, pInkStrokeIterable: win32more.Windows.Win32.System.Com.IUnknown, fHighContrast: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IInkD2DRenderer2(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0a95dcd9-4578-4b71-b20b-bf664d4bfeee}')
    @commethod(3)
    def Draw(self, pD2D1DeviceContext: win32more.Windows.Win32.System.Com.IUnknown, pInkStrokeIterable: win32more.Windows.Win32.System.Com.IUnknown, highContrastAdjustment: win32more.Windows.Win32.UI.Input.Ink.INK_HIGH_CONTRAST_ADJUSTMENT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IInkDesktopHost(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{4ce7d875-a981-4140-a1ff-ad93258e8d59}')
    @commethod(3)
    def QueueWorkItem(self, workItem: win32more.Windows.Win32.UI.Input.Ink.IInkHostWorkItem) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def CreateInkPresenter(self, riid: POINTER(Guid), ppv: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def CreateAndInitializeInkPresenter(self, rootVisual: win32more.Windows.Win32.System.Com.IUnknown, width: Single, height: Single, riid: POINTER(Guid), ppv: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IInkHostWorkItem(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{ccda0a9a-1b78-4632-bb96-97800662e26c}')
    @commethod(3)
    def Invoke(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IInkPresenterDesktop(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{73f3c0d9-2e8b-48f3-895e-20cbd27b723b}')
    @commethod(3)
    def SetRootVisual(self, rootVisual: win32more.Windows.Win32.System.Com.IUnknown, device: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetCommitRequestHandler(self, handler: win32more.Windows.Win32.UI.Input.Ink.IInkCommitRequestHandler) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetSize(self, width: POINTER(Single), height: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetSize(self, width: Single, height: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def OnHighContrastChanged(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
INK_HIGH_CONTRAST_ADJUSTMENT = Int32
USE_SYSTEM_COLORS_WHEN_NECESSARY: win32more.Windows.Win32.UI.Input.Ink.INK_HIGH_CONTRAST_ADJUSTMENT = 0
USE_SYSTEM_COLORS: win32more.Windows.Win32.UI.Input.Ink.INK_HIGH_CONTRAST_ADJUSTMENT = 1
USE_ORIGINAL_COLORS: win32more.Windows.Win32.UI.Input.Ink.INK_HIGH_CONTRAST_ADJUSTMENT = 2
InkD2DRenderer = Guid('{4044e60c-7b01-4671-a97c-04e0210a07a5}')
InkDesktopHost = Guid('{062584a6-f830-4bdc-a4d2-0a10ab062b1d}')


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Security
import win32more.Windows.Win32.System.EventLog
EVT_VARIANT_TYPE_MASK: UInt32 = 127
EVT_VARIANT_TYPE_ARRAY: UInt32 = 128
EVT_READ_ACCESS: UInt32 = 1
EVT_WRITE_ACCESS: UInt32 = 2
EVT_CLEAR_ACCESS: UInt32 = 4
EVT_ALL_ACCESS: UInt32 = 7
@winfunctype('wevtapi.dll')
def EvtOpenSession(LoginClass: win32more.Windows.Win32.System.EventLog.EVT_LOGIN_CLASS, Login: VoidPtr, Timeout: UInt32, Flags: UInt32) -> win32more.Windows.Win32.System.EventLog.EVT_HANDLE: ...
@winfunctype('wevtapi.dll')
def EvtClose(Object: win32more.Windows.Win32.System.EventLog.EVT_HANDLE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('wevtapi.dll')
def EvtCancel(Object: win32more.Windows.Win32.System.EventLog.EVT_HANDLE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('wevtapi.dll')
def EvtGetExtendedStatus(BufferSize: UInt32, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferUsed: POINTER(UInt32)) -> UInt32: ...
@winfunctype('wevtapi.dll')
def EvtQuery(Session: win32more.Windows.Win32.System.EventLog.EVT_HANDLE, Path: win32more.Windows.Win32.Foundation.PWSTR, Query: win32more.Windows.Win32.Foundation.PWSTR, Flags: UInt32) -> win32more.Windows.Win32.System.EventLog.EVT_HANDLE: ...
@winfunctype('wevtapi.dll')
def EvtNext(ResultSet: win32more.Windows.Win32.System.EventLog.EVT_HANDLE, EventsSize: UInt32, Events: POINTER(IntPtr), Timeout: UInt32, Flags: UInt32, Returned: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('wevtapi.dll')
def EvtSeek(ResultSet: win32more.Windows.Win32.System.EventLog.EVT_HANDLE, Position: Int64, Bookmark: win32more.Windows.Win32.System.EventLog.EVT_HANDLE, Timeout: UInt32, Flags: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('wevtapi.dll')
def EvtSubscribe(Session: win32more.Windows.Win32.System.EventLog.EVT_HANDLE, SignalEvent: win32more.Windows.Win32.Foundation.HANDLE, ChannelPath: win32more.Windows.Win32.Foundation.PWSTR, Query: win32more.Windows.Win32.Foundation.PWSTR, Bookmark: win32more.Windows.Win32.System.EventLog.EVT_HANDLE, Context: VoidPtr, Callback: win32more.Windows.Win32.System.EventLog.EVT_SUBSCRIBE_CALLBACK, Flags: UInt32) -> win32more.Windows.Win32.System.EventLog.EVT_HANDLE: ...
@winfunctype('wevtapi.dll')
def EvtCreateRenderContext(ValuePathsCount: UInt32, ValuePaths: POINTER(win32more.Windows.Win32.Foundation.PWSTR), Flags: UInt32) -> win32more.Windows.Win32.System.EventLog.EVT_HANDLE: ...
@winfunctype('wevtapi.dll')
def EvtRender(Context: win32more.Windows.Win32.System.EventLog.EVT_HANDLE, Fragment: win32more.Windows.Win32.System.EventLog.EVT_HANDLE, Flags: UInt32, BufferSize: UInt32, Buffer: VoidPtr, BufferUsed: POINTER(UInt32), PropertyCount: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('wevtapi.dll')
def EvtFormatMessage(PublisherMetadata: win32more.Windows.Win32.System.EventLog.EVT_HANDLE, Event: win32more.Windows.Win32.System.EventLog.EVT_HANDLE, MessageId: UInt32, ValueCount: UInt32, Values: POINTER(win32more.Windows.Win32.System.EventLog.EVT_VARIANT), Flags: UInt32, BufferSize: UInt32, Buffer: win32more.Windows.Win32.Foundation.PWSTR, BufferUsed: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('wevtapi.dll')
def EvtOpenLog(Session: win32more.Windows.Win32.System.EventLog.EVT_HANDLE, Path: win32more.Windows.Win32.Foundation.PWSTR, Flags: UInt32) -> win32more.Windows.Win32.System.EventLog.EVT_HANDLE: ...
@winfunctype('wevtapi.dll')
def EvtGetLogInfo(Log: win32more.Windows.Win32.System.EventLog.EVT_HANDLE, PropertyId: win32more.Windows.Win32.System.EventLog.EVT_LOG_PROPERTY_ID, PropertyValueBufferSize: UInt32, PropertyValueBuffer: POINTER(win32more.Windows.Win32.System.EventLog.EVT_VARIANT), PropertyValueBufferUsed: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('wevtapi.dll')
def EvtClearLog(Session: win32more.Windows.Win32.System.EventLog.EVT_HANDLE, ChannelPath: win32more.Windows.Win32.Foundation.PWSTR, TargetFilePath: win32more.Windows.Win32.Foundation.PWSTR, Flags: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('wevtapi.dll')
def EvtExportLog(Session: win32more.Windows.Win32.System.EventLog.EVT_HANDLE, Path: win32more.Windows.Win32.Foundation.PWSTR, Query: win32more.Windows.Win32.Foundation.PWSTR, TargetFilePath: win32more.Windows.Win32.Foundation.PWSTR, Flags: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('wevtapi.dll')
def EvtArchiveExportedLog(Session: win32more.Windows.Win32.System.EventLog.EVT_HANDLE, LogFilePath: win32more.Windows.Win32.Foundation.PWSTR, Locale: UInt32, Flags: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('wevtapi.dll')
def EvtOpenChannelEnum(Session: win32more.Windows.Win32.System.EventLog.EVT_HANDLE, Flags: UInt32) -> win32more.Windows.Win32.System.EventLog.EVT_HANDLE: ...
@winfunctype('wevtapi.dll')
def EvtNextChannelPath(ChannelEnum: win32more.Windows.Win32.System.EventLog.EVT_HANDLE, ChannelPathBufferSize: UInt32, ChannelPathBuffer: win32more.Windows.Win32.Foundation.PWSTR, ChannelPathBufferUsed: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('wevtapi.dll')
def EvtOpenChannelConfig(Session: win32more.Windows.Win32.System.EventLog.EVT_HANDLE, ChannelPath: win32more.Windows.Win32.Foundation.PWSTR, Flags: UInt32) -> win32more.Windows.Win32.System.EventLog.EVT_HANDLE: ...
@winfunctype('wevtapi.dll')
def EvtSaveChannelConfig(ChannelConfig: win32more.Windows.Win32.System.EventLog.EVT_HANDLE, Flags: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('wevtapi.dll')
def EvtSetChannelConfigProperty(ChannelConfig: win32more.Windows.Win32.System.EventLog.EVT_HANDLE, PropertyId: win32more.Windows.Win32.System.EventLog.EVT_CHANNEL_CONFIG_PROPERTY_ID, Flags: UInt32, PropertyValue: POINTER(win32more.Windows.Win32.System.EventLog.EVT_VARIANT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('wevtapi.dll')
def EvtGetChannelConfigProperty(ChannelConfig: win32more.Windows.Win32.System.EventLog.EVT_HANDLE, PropertyId: win32more.Windows.Win32.System.EventLog.EVT_CHANNEL_CONFIG_PROPERTY_ID, Flags: UInt32, PropertyValueBufferSize: UInt32, PropertyValueBuffer: POINTER(win32more.Windows.Win32.System.EventLog.EVT_VARIANT), PropertyValueBufferUsed: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('wevtapi.dll')
def EvtOpenPublisherEnum(Session: win32more.Windows.Win32.System.EventLog.EVT_HANDLE, Flags: UInt32) -> win32more.Windows.Win32.System.EventLog.EVT_HANDLE: ...
@winfunctype('wevtapi.dll')
def EvtNextPublisherId(PublisherEnum: win32more.Windows.Win32.System.EventLog.EVT_HANDLE, PublisherIdBufferSize: UInt32, PublisherIdBuffer: win32more.Windows.Win32.Foundation.PWSTR, PublisherIdBufferUsed: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('wevtapi.dll')
def EvtOpenPublisherMetadata(Session: win32more.Windows.Win32.System.EventLog.EVT_HANDLE, PublisherId: win32more.Windows.Win32.Foundation.PWSTR, LogFilePath: win32more.Windows.Win32.Foundation.PWSTR, Locale: UInt32, Flags: UInt32) -> win32more.Windows.Win32.System.EventLog.EVT_HANDLE: ...
@winfunctype('wevtapi.dll')
def EvtGetPublisherMetadataProperty(PublisherMetadata: win32more.Windows.Win32.System.EventLog.EVT_HANDLE, PropertyId: win32more.Windows.Win32.System.EventLog.EVT_PUBLISHER_METADATA_PROPERTY_ID, Flags: UInt32, PublisherMetadataPropertyBufferSize: UInt32, PublisherMetadataPropertyBuffer: POINTER(win32more.Windows.Win32.System.EventLog.EVT_VARIANT), PublisherMetadataPropertyBufferUsed: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('wevtapi.dll')
def EvtOpenEventMetadataEnum(PublisherMetadata: win32more.Windows.Win32.System.EventLog.EVT_HANDLE, Flags: UInt32) -> win32more.Windows.Win32.System.EventLog.EVT_HANDLE: ...
@winfunctype('wevtapi.dll')
def EvtNextEventMetadata(EventMetadataEnum: win32more.Windows.Win32.System.EventLog.EVT_HANDLE, Flags: UInt32) -> win32more.Windows.Win32.System.EventLog.EVT_HANDLE: ...
@winfunctype('wevtapi.dll')
def EvtGetEventMetadataProperty(EventMetadata: win32more.Windows.Win32.System.EventLog.EVT_HANDLE, PropertyId: win32more.Windows.Win32.System.EventLog.EVT_EVENT_METADATA_PROPERTY_ID, Flags: UInt32, EventMetadataPropertyBufferSize: UInt32, EventMetadataPropertyBuffer: POINTER(win32more.Windows.Win32.System.EventLog.EVT_VARIANT), EventMetadataPropertyBufferUsed: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('wevtapi.dll')
def EvtGetObjectArraySize(ObjectArray: IntPtr, ObjectArraySize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('wevtapi.dll')
def EvtGetObjectArrayProperty(ObjectArray: IntPtr, PropertyId: UInt32, ArrayIndex: UInt32, Flags: UInt32, PropertyValueBufferSize: UInt32, PropertyValueBuffer: POINTER(win32more.Windows.Win32.System.EventLog.EVT_VARIANT), PropertyValueBufferUsed: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('wevtapi.dll')
def EvtGetQueryInfo(QueryOrSubscription: win32more.Windows.Win32.System.EventLog.EVT_HANDLE, PropertyId: win32more.Windows.Win32.System.EventLog.EVT_QUERY_PROPERTY_ID, PropertyValueBufferSize: UInt32, PropertyValueBuffer: POINTER(win32more.Windows.Win32.System.EventLog.EVT_VARIANT), PropertyValueBufferUsed: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('wevtapi.dll')
def EvtCreateBookmark(BookmarkXml: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.System.EventLog.EVT_HANDLE: ...
@winfunctype('wevtapi.dll')
def EvtUpdateBookmark(Bookmark: win32more.Windows.Win32.System.EventLog.EVT_HANDLE, Event: win32more.Windows.Win32.System.EventLog.EVT_HANDLE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('wevtapi.dll')
def EvtGetEventInfo(Event: win32more.Windows.Win32.System.EventLog.EVT_HANDLE, PropertyId: win32more.Windows.Win32.System.EventLog.EVT_EVENT_PROPERTY_ID, PropertyValueBufferSize: UInt32, PropertyValueBuffer: POINTER(win32more.Windows.Win32.System.EventLog.EVT_VARIANT), PropertyValueBufferUsed: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('ADVAPI32.dll')
def ClearEventLogA(hEventLog: win32more.Windows.Win32.Foundation.HANDLE, lpBackupFileName: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('ADVAPI32.dll')
def ClearEventLogW(hEventLog: win32more.Windows.Win32.Foundation.HANDLE, lpBackupFileName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
ClearEventLog = UnicodeAlias('ClearEventLogW')
@winfunctype('ADVAPI32.dll')
def BackupEventLogA(hEventLog: win32more.Windows.Win32.Foundation.HANDLE, lpBackupFileName: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('ADVAPI32.dll')
def BackupEventLogW(hEventLog: win32more.Windows.Win32.Foundation.HANDLE, lpBackupFileName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
BackupEventLog = UnicodeAlias('BackupEventLogW')
@winfunctype('ADVAPI32.dll')
def CloseEventLog(hEventLog: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('ADVAPI32.dll')
def DeregisterEventSource(hEventLog: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('ADVAPI32.dll')
def NotifyChangeEventLog(hEventLog: win32more.Windows.Win32.Foundation.HANDLE, hEvent: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('ADVAPI32.dll')
def GetNumberOfEventLogRecords(hEventLog: win32more.Windows.Win32.Foundation.HANDLE, NumberOfRecords: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('ADVAPI32.dll')
def GetOldestEventLogRecord(hEventLog: win32more.Windows.Win32.Foundation.HANDLE, OldestRecord: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('ADVAPI32.dll')
def OpenEventLogA(lpUNCServerName: win32more.Windows.Win32.Foundation.PSTR, lpSourceName: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HANDLE: ...
@winfunctype('ADVAPI32.dll')
def OpenEventLogW(lpUNCServerName: win32more.Windows.Win32.Foundation.PWSTR, lpSourceName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HANDLE: ...
OpenEventLog = UnicodeAlias('OpenEventLogW')
@winfunctype('ADVAPI32.dll')
def RegisterEventSourceA(lpUNCServerName: win32more.Windows.Win32.Foundation.PSTR, lpSourceName: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HANDLE: ...
@winfunctype('ADVAPI32.dll')
def RegisterEventSourceW(lpUNCServerName: win32more.Windows.Win32.Foundation.PWSTR, lpSourceName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HANDLE: ...
RegisterEventSource = UnicodeAlias('RegisterEventSourceW')
@winfunctype('ADVAPI32.dll')
def OpenBackupEventLogA(lpUNCServerName: win32more.Windows.Win32.Foundation.PSTR, lpFileName: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.HANDLE: ...
@winfunctype('ADVAPI32.dll')
def OpenBackupEventLogW(lpUNCServerName: win32more.Windows.Win32.Foundation.PWSTR, lpFileName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HANDLE: ...
OpenBackupEventLog = UnicodeAlias('OpenBackupEventLogW')
@winfunctype('ADVAPI32.dll')
def ReadEventLogA(hEventLog: win32more.Windows.Win32.Foundation.HANDLE, dwReadFlags: win32more.Windows.Win32.System.EventLog.READ_EVENT_LOG_READ_FLAGS, dwRecordOffset: UInt32, lpBuffer: VoidPtr, nNumberOfBytesToRead: UInt32, pnBytesRead: POINTER(UInt32), pnMinNumberOfBytesNeeded: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('ADVAPI32.dll')
def ReadEventLogW(hEventLog: win32more.Windows.Win32.Foundation.HANDLE, dwReadFlags: win32more.Windows.Win32.System.EventLog.READ_EVENT_LOG_READ_FLAGS, dwRecordOffset: UInt32, lpBuffer: VoidPtr, nNumberOfBytesToRead: UInt32, pnBytesRead: POINTER(UInt32), pnMinNumberOfBytesNeeded: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
ReadEventLog = UnicodeAlias('ReadEventLogW')
@winfunctype('ADVAPI32.dll')
def ReportEventA(hEventLog: win32more.Windows.Win32.Foundation.HANDLE, wType: win32more.Windows.Win32.System.EventLog.REPORT_EVENT_TYPE, wCategory: UInt16, dwEventID: UInt32, lpUserSid: win32more.Windows.Win32.Security.PSID, wNumStrings: UInt16, dwDataSize: UInt32, lpStrings: POINTER(win32more.Windows.Win32.Foundation.PSTR), lpRawData: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('ADVAPI32.dll')
def ReportEventW(hEventLog: win32more.Windows.Win32.Foundation.HANDLE, wType: win32more.Windows.Win32.System.EventLog.REPORT_EVENT_TYPE, wCategory: UInt16, dwEventID: UInt32, lpUserSid: win32more.Windows.Win32.Security.PSID, wNumStrings: UInt16, dwDataSize: UInt32, lpStrings: POINTER(win32more.Windows.Win32.Foundation.PWSTR), lpRawData: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
ReportEvent = UnicodeAlias('ReportEventW')
@winfunctype('ADVAPI32.dll')
def GetEventLogInformation(hEventLog: win32more.Windows.Win32.Foundation.HANDLE, dwInfoLevel: UInt32, lpBuffer: VoidPtr, cbBufSize: UInt32, pcbBytesNeeded: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
class EVENTLOGRECORD(Structure):
    Length: UInt32
    Reserved: UInt32
    RecordNumber: UInt32
    TimeGenerated: UInt32
    TimeWritten: UInt32
    EventID: UInt32
    EventType: win32more.Windows.Win32.System.EventLog.REPORT_EVENT_TYPE
    NumStrings: UInt16
    EventCategory: UInt16
    ReservedFlags: UInt16
    ClosingRecordNumber: UInt32
    StringOffset: UInt32
    UserSidLength: UInt32
    UserSidOffset: UInt32
    DataLength: UInt32
    DataOffset: UInt32
class EVENTLOG_FULL_INFORMATION(Structure):
    dwFull: UInt32
class EVENTSFORLOGFILE(Structure):
    ulSize: UInt32
    szLogicalLogFile: Char * 256
    ulNumRecords: UInt32
    pEventLogRecords: win32more.Windows.Win32.System.EventLog.EVENTLOGRECORD * 1
EVT_CHANNEL_CLOCK_TYPE = Int32
EvtChannelClockTypeSystemTime: win32more.Windows.Win32.System.EventLog.EVT_CHANNEL_CLOCK_TYPE = 0
EvtChannelClockTypeQPC: win32more.Windows.Win32.System.EventLog.EVT_CHANNEL_CLOCK_TYPE = 1
EVT_CHANNEL_CONFIG_PROPERTY_ID = Int32
EvtChannelConfigEnabled: win32more.Windows.Win32.System.EventLog.EVT_CHANNEL_CONFIG_PROPERTY_ID = 0
EvtChannelConfigIsolation: win32more.Windows.Win32.System.EventLog.EVT_CHANNEL_CONFIG_PROPERTY_ID = 1
EvtChannelConfigType: win32more.Windows.Win32.System.EventLog.EVT_CHANNEL_CONFIG_PROPERTY_ID = 2
EvtChannelConfigOwningPublisher: win32more.Windows.Win32.System.EventLog.EVT_CHANNEL_CONFIG_PROPERTY_ID = 3
EvtChannelConfigClassicEventlog: win32more.Windows.Win32.System.EventLog.EVT_CHANNEL_CONFIG_PROPERTY_ID = 4
EvtChannelConfigAccess: win32more.Windows.Win32.System.EventLog.EVT_CHANNEL_CONFIG_PROPERTY_ID = 5
EvtChannelLoggingConfigRetention: win32more.Windows.Win32.System.EventLog.EVT_CHANNEL_CONFIG_PROPERTY_ID = 6
EvtChannelLoggingConfigAutoBackup: win32more.Windows.Win32.System.EventLog.EVT_CHANNEL_CONFIG_PROPERTY_ID = 7
EvtChannelLoggingConfigMaxSize: win32more.Windows.Win32.System.EventLog.EVT_CHANNEL_CONFIG_PROPERTY_ID = 8
EvtChannelLoggingConfigLogFilePath: win32more.Windows.Win32.System.EventLog.EVT_CHANNEL_CONFIG_PROPERTY_ID = 9
EvtChannelPublishingConfigLevel: win32more.Windows.Win32.System.EventLog.EVT_CHANNEL_CONFIG_PROPERTY_ID = 10
EvtChannelPublishingConfigKeywords: win32more.Windows.Win32.System.EventLog.EVT_CHANNEL_CONFIG_PROPERTY_ID = 11
EvtChannelPublishingConfigControlGuid: win32more.Windows.Win32.System.EventLog.EVT_CHANNEL_CONFIG_PROPERTY_ID = 12
EvtChannelPublishingConfigBufferSize: win32more.Windows.Win32.System.EventLog.EVT_CHANNEL_CONFIG_PROPERTY_ID = 13
EvtChannelPublishingConfigMinBuffers: win32more.Windows.Win32.System.EventLog.EVT_CHANNEL_CONFIG_PROPERTY_ID = 14
EvtChannelPublishingConfigMaxBuffers: win32more.Windows.Win32.System.EventLog.EVT_CHANNEL_CONFIG_PROPERTY_ID = 15
EvtChannelPublishingConfigLatency: win32more.Windows.Win32.System.EventLog.EVT_CHANNEL_CONFIG_PROPERTY_ID = 16
EvtChannelPublishingConfigClockType: win32more.Windows.Win32.System.EventLog.EVT_CHANNEL_CONFIG_PROPERTY_ID = 17
EvtChannelPublishingConfigSidType: win32more.Windows.Win32.System.EventLog.EVT_CHANNEL_CONFIG_PROPERTY_ID = 18
EvtChannelPublisherList: win32more.Windows.Win32.System.EventLog.EVT_CHANNEL_CONFIG_PROPERTY_ID = 19
EvtChannelPublishingConfigFileMax: win32more.Windows.Win32.System.EventLog.EVT_CHANNEL_CONFIG_PROPERTY_ID = 20
EvtChannelConfigPropertyIdEND: win32more.Windows.Win32.System.EventLog.EVT_CHANNEL_CONFIG_PROPERTY_ID = 21
EVT_CHANNEL_ISOLATION_TYPE = Int32
EvtChannelIsolationTypeApplication: win32more.Windows.Win32.System.EventLog.EVT_CHANNEL_ISOLATION_TYPE = 0
EvtChannelIsolationTypeSystem: win32more.Windows.Win32.System.EventLog.EVT_CHANNEL_ISOLATION_TYPE = 1
EvtChannelIsolationTypeCustom: win32more.Windows.Win32.System.EventLog.EVT_CHANNEL_ISOLATION_TYPE = 2
EVT_CHANNEL_REFERENCE_FLAGS = UInt32
EvtChannelReferenceImported: win32more.Windows.Win32.System.EventLog.EVT_CHANNEL_REFERENCE_FLAGS = 1
EVT_CHANNEL_SID_TYPE = Int32
EvtChannelSidTypeNone: win32more.Windows.Win32.System.EventLog.EVT_CHANNEL_SID_TYPE = 0
EvtChannelSidTypePublishing: win32more.Windows.Win32.System.EventLog.EVT_CHANNEL_SID_TYPE = 1
EVT_CHANNEL_TYPE = Int32
EvtChannelTypeAdmin: win32more.Windows.Win32.System.EventLog.EVT_CHANNEL_TYPE = 0
EvtChannelTypeOperational: win32more.Windows.Win32.System.EventLog.EVT_CHANNEL_TYPE = 1
EvtChannelTypeAnalytic: win32more.Windows.Win32.System.EventLog.EVT_CHANNEL_TYPE = 2
EvtChannelTypeDebug: win32more.Windows.Win32.System.EventLog.EVT_CHANNEL_TYPE = 3
EVT_EVENT_METADATA_PROPERTY_ID = Int32
EventMetadataEventID: win32more.Windows.Win32.System.EventLog.EVT_EVENT_METADATA_PROPERTY_ID = 0
EventMetadataEventVersion: win32more.Windows.Win32.System.EventLog.EVT_EVENT_METADATA_PROPERTY_ID = 1
EventMetadataEventChannel: win32more.Windows.Win32.System.EventLog.EVT_EVENT_METADATA_PROPERTY_ID = 2
EventMetadataEventLevel: win32more.Windows.Win32.System.EventLog.EVT_EVENT_METADATA_PROPERTY_ID = 3
EventMetadataEventOpcode: win32more.Windows.Win32.System.EventLog.EVT_EVENT_METADATA_PROPERTY_ID = 4
EventMetadataEventTask: win32more.Windows.Win32.System.EventLog.EVT_EVENT_METADATA_PROPERTY_ID = 5
EventMetadataEventKeyword: win32more.Windows.Win32.System.EventLog.EVT_EVENT_METADATA_PROPERTY_ID = 6
EventMetadataEventMessageID: win32more.Windows.Win32.System.EventLog.EVT_EVENT_METADATA_PROPERTY_ID = 7
EventMetadataEventTemplate: win32more.Windows.Win32.System.EventLog.EVT_EVENT_METADATA_PROPERTY_ID = 8
EvtEventMetadataPropertyIdEND: win32more.Windows.Win32.System.EventLog.EVT_EVENT_METADATA_PROPERTY_ID = 9
EVT_EVENT_PROPERTY_ID = Int32
EvtEventQueryIDs: win32more.Windows.Win32.System.EventLog.EVT_EVENT_PROPERTY_ID = 0
EvtEventPath: win32more.Windows.Win32.System.EventLog.EVT_EVENT_PROPERTY_ID = 1
EvtEventPropertyIdEND: win32more.Windows.Win32.System.EventLog.EVT_EVENT_PROPERTY_ID = 2
EVT_EXPORTLOG_FLAGS = UInt32
EvtExportLogChannelPath: win32more.Windows.Win32.System.EventLog.EVT_EXPORTLOG_FLAGS = 1
EvtExportLogFilePath: win32more.Windows.Win32.System.EventLog.EVT_EXPORTLOG_FLAGS = 2
EvtExportLogTolerateQueryErrors: win32more.Windows.Win32.System.EventLog.EVT_EXPORTLOG_FLAGS = 4096
EvtExportLogOverwrite: win32more.Windows.Win32.System.EventLog.EVT_EXPORTLOG_FLAGS = 8192
EVT_FORMAT_MESSAGE_FLAGS = UInt32
EvtFormatMessageEvent: win32more.Windows.Win32.System.EventLog.EVT_FORMAT_MESSAGE_FLAGS = 1
EvtFormatMessageLevel: win32more.Windows.Win32.System.EventLog.EVT_FORMAT_MESSAGE_FLAGS = 2
EvtFormatMessageTask: win32more.Windows.Win32.System.EventLog.EVT_FORMAT_MESSAGE_FLAGS = 3
EvtFormatMessageOpcode: win32more.Windows.Win32.System.EventLog.EVT_FORMAT_MESSAGE_FLAGS = 4
EvtFormatMessageKeyword: win32more.Windows.Win32.System.EventLog.EVT_FORMAT_MESSAGE_FLAGS = 5
EvtFormatMessageChannel: win32more.Windows.Win32.System.EventLog.EVT_FORMAT_MESSAGE_FLAGS = 6
EvtFormatMessageProvider: win32more.Windows.Win32.System.EventLog.EVT_FORMAT_MESSAGE_FLAGS = 7
EvtFormatMessageId: win32more.Windows.Win32.System.EventLog.EVT_FORMAT_MESSAGE_FLAGS = 8
EvtFormatMessageXml: win32more.Windows.Win32.System.EventLog.EVT_FORMAT_MESSAGE_FLAGS = 9
EVT_HANDLE = IntPtr
EVT_LOGIN_CLASS = Int32
EvtRpcLogin: win32more.Windows.Win32.System.EventLog.EVT_LOGIN_CLASS = 1
EVT_LOG_PROPERTY_ID = Int32
EvtLogCreationTime: win32more.Windows.Win32.System.EventLog.EVT_LOG_PROPERTY_ID = 0
EvtLogLastAccessTime: win32more.Windows.Win32.System.EventLog.EVT_LOG_PROPERTY_ID = 1
EvtLogLastWriteTime: win32more.Windows.Win32.System.EventLog.EVT_LOG_PROPERTY_ID = 2
EvtLogFileSize: win32more.Windows.Win32.System.EventLog.EVT_LOG_PROPERTY_ID = 3
EvtLogAttributes: win32more.Windows.Win32.System.EventLog.EVT_LOG_PROPERTY_ID = 4
EvtLogNumberOfLogRecords: win32more.Windows.Win32.System.EventLog.EVT_LOG_PROPERTY_ID = 5
EvtLogOldestRecordNumber: win32more.Windows.Win32.System.EventLog.EVT_LOG_PROPERTY_ID = 6
EvtLogFull: win32more.Windows.Win32.System.EventLog.EVT_LOG_PROPERTY_ID = 7
EVT_OPEN_LOG_FLAGS = UInt32
EvtOpenChannelPath: win32more.Windows.Win32.System.EventLog.EVT_OPEN_LOG_FLAGS = 1
EvtOpenFilePath: win32more.Windows.Win32.System.EventLog.EVT_OPEN_LOG_FLAGS = 2
EVT_PUBLISHER_METADATA_PROPERTY_ID = Int32
EvtPublisherMetadataPublisherGuid: win32more.Windows.Win32.System.EventLog.EVT_PUBLISHER_METADATA_PROPERTY_ID = 0
EvtPublisherMetadataResourceFilePath: win32more.Windows.Win32.System.EventLog.EVT_PUBLISHER_METADATA_PROPERTY_ID = 1
EvtPublisherMetadataParameterFilePath: win32more.Windows.Win32.System.EventLog.EVT_PUBLISHER_METADATA_PROPERTY_ID = 2
EvtPublisherMetadataMessageFilePath: win32more.Windows.Win32.System.EventLog.EVT_PUBLISHER_METADATA_PROPERTY_ID = 3
EvtPublisherMetadataHelpLink: win32more.Windows.Win32.System.EventLog.EVT_PUBLISHER_METADATA_PROPERTY_ID = 4
EvtPublisherMetadataPublisherMessageID: win32more.Windows.Win32.System.EventLog.EVT_PUBLISHER_METADATA_PROPERTY_ID = 5
EvtPublisherMetadataChannelReferences: win32more.Windows.Win32.System.EventLog.EVT_PUBLISHER_METADATA_PROPERTY_ID = 6
EvtPublisherMetadataChannelReferencePath: win32more.Windows.Win32.System.EventLog.EVT_PUBLISHER_METADATA_PROPERTY_ID = 7
EvtPublisherMetadataChannelReferenceIndex: win32more.Windows.Win32.System.EventLog.EVT_PUBLISHER_METADATA_PROPERTY_ID = 8
EvtPublisherMetadataChannelReferenceID: win32more.Windows.Win32.System.EventLog.EVT_PUBLISHER_METADATA_PROPERTY_ID = 9
EvtPublisherMetadataChannelReferenceFlags: win32more.Windows.Win32.System.EventLog.EVT_PUBLISHER_METADATA_PROPERTY_ID = 10
EvtPublisherMetadataChannelReferenceMessageID: win32more.Windows.Win32.System.EventLog.EVT_PUBLISHER_METADATA_PROPERTY_ID = 11
EvtPublisherMetadataLevels: win32more.Windows.Win32.System.EventLog.EVT_PUBLISHER_METADATA_PROPERTY_ID = 12
EvtPublisherMetadataLevelName: win32more.Windows.Win32.System.EventLog.EVT_PUBLISHER_METADATA_PROPERTY_ID = 13
EvtPublisherMetadataLevelValue: win32more.Windows.Win32.System.EventLog.EVT_PUBLISHER_METADATA_PROPERTY_ID = 14
EvtPublisherMetadataLevelMessageID: win32more.Windows.Win32.System.EventLog.EVT_PUBLISHER_METADATA_PROPERTY_ID = 15
EvtPublisherMetadataTasks: win32more.Windows.Win32.System.EventLog.EVT_PUBLISHER_METADATA_PROPERTY_ID = 16
EvtPublisherMetadataTaskName: win32more.Windows.Win32.System.EventLog.EVT_PUBLISHER_METADATA_PROPERTY_ID = 17
EvtPublisherMetadataTaskEventGuid: win32more.Windows.Win32.System.EventLog.EVT_PUBLISHER_METADATA_PROPERTY_ID = 18
EvtPublisherMetadataTaskValue: win32more.Windows.Win32.System.EventLog.EVT_PUBLISHER_METADATA_PROPERTY_ID = 19
EvtPublisherMetadataTaskMessageID: win32more.Windows.Win32.System.EventLog.EVT_PUBLISHER_METADATA_PROPERTY_ID = 20
EvtPublisherMetadataOpcodes: win32more.Windows.Win32.System.EventLog.EVT_PUBLISHER_METADATA_PROPERTY_ID = 21
EvtPublisherMetadataOpcodeName: win32more.Windows.Win32.System.EventLog.EVT_PUBLISHER_METADATA_PROPERTY_ID = 22
EvtPublisherMetadataOpcodeValue: win32more.Windows.Win32.System.EventLog.EVT_PUBLISHER_METADATA_PROPERTY_ID = 23
EvtPublisherMetadataOpcodeMessageID: win32more.Windows.Win32.System.EventLog.EVT_PUBLISHER_METADATA_PROPERTY_ID = 24
EvtPublisherMetadataKeywords: win32more.Windows.Win32.System.EventLog.EVT_PUBLISHER_METADATA_PROPERTY_ID = 25
EvtPublisherMetadataKeywordName: win32more.Windows.Win32.System.EventLog.EVT_PUBLISHER_METADATA_PROPERTY_ID = 26
EvtPublisherMetadataKeywordValue: win32more.Windows.Win32.System.EventLog.EVT_PUBLISHER_METADATA_PROPERTY_ID = 27
EvtPublisherMetadataKeywordMessageID: win32more.Windows.Win32.System.EventLog.EVT_PUBLISHER_METADATA_PROPERTY_ID = 28
EvtPublisherMetadataPropertyIdEND: win32more.Windows.Win32.System.EventLog.EVT_PUBLISHER_METADATA_PROPERTY_ID = 29
EVT_QUERY_FLAGS = UInt32
EvtQueryChannelPath: win32more.Windows.Win32.System.EventLog.EVT_QUERY_FLAGS = 1
EvtQueryFilePath: win32more.Windows.Win32.System.EventLog.EVT_QUERY_FLAGS = 2
EvtQueryForwardDirection: win32more.Windows.Win32.System.EventLog.EVT_QUERY_FLAGS = 256
EvtQueryReverseDirection: win32more.Windows.Win32.System.EventLog.EVT_QUERY_FLAGS = 512
EvtQueryTolerateQueryErrors: win32more.Windows.Win32.System.EventLog.EVT_QUERY_FLAGS = 4096
EVT_QUERY_PROPERTY_ID = Int32
EvtQueryNames: win32more.Windows.Win32.System.EventLog.EVT_QUERY_PROPERTY_ID = 0
EvtQueryStatuses: win32more.Windows.Win32.System.EventLog.EVT_QUERY_PROPERTY_ID = 1
EvtQueryPropertyIdEND: win32more.Windows.Win32.System.EventLog.EVT_QUERY_PROPERTY_ID = 2
EVT_RENDER_CONTEXT_FLAGS = UInt32
EvtRenderContextValues: win32more.Windows.Win32.System.EventLog.EVT_RENDER_CONTEXT_FLAGS = 0
EvtRenderContextSystem: win32more.Windows.Win32.System.EventLog.EVT_RENDER_CONTEXT_FLAGS = 1
EvtRenderContextUser: win32more.Windows.Win32.System.EventLog.EVT_RENDER_CONTEXT_FLAGS = 2
EVT_RENDER_FLAGS = UInt32
EvtRenderEventValues: win32more.Windows.Win32.System.EventLog.EVT_RENDER_FLAGS = 0
EvtRenderEventXml: win32more.Windows.Win32.System.EventLog.EVT_RENDER_FLAGS = 1
EvtRenderBookmark: win32more.Windows.Win32.System.EventLog.EVT_RENDER_FLAGS = 2
class EVT_RPC_LOGIN(Structure):
    Server: win32more.Windows.Win32.Foundation.PWSTR
    User: win32more.Windows.Win32.Foundation.PWSTR
    Domain: win32more.Windows.Win32.Foundation.PWSTR
    Password: win32more.Windows.Win32.Foundation.PWSTR
    Flags: UInt32
EVT_RPC_LOGIN_FLAGS = UInt32
EvtRpcLoginAuthDefault: win32more.Windows.Win32.System.EventLog.EVT_RPC_LOGIN_FLAGS = 0
EvtRpcLoginAuthNegotiate: win32more.Windows.Win32.System.EventLog.EVT_RPC_LOGIN_FLAGS = 1
EvtRpcLoginAuthKerberos: win32more.Windows.Win32.System.EventLog.EVT_RPC_LOGIN_FLAGS = 2
EvtRpcLoginAuthNTLM: win32more.Windows.Win32.System.EventLog.EVT_RPC_LOGIN_FLAGS = 3
EVT_SEEK_FLAGS = UInt32
EvtSeekRelativeToFirst: win32more.Windows.Win32.System.EventLog.EVT_SEEK_FLAGS = 1
EvtSeekRelativeToLast: win32more.Windows.Win32.System.EventLog.EVT_SEEK_FLAGS = 2
EvtSeekRelativeToCurrent: win32more.Windows.Win32.System.EventLog.EVT_SEEK_FLAGS = 3
EvtSeekRelativeToBookmark: win32more.Windows.Win32.System.EventLog.EVT_SEEK_FLAGS = 4
EvtSeekOriginMask: win32more.Windows.Win32.System.EventLog.EVT_SEEK_FLAGS = 7
EvtSeekStrict: win32more.Windows.Win32.System.EventLog.EVT_SEEK_FLAGS = 65536
@winfunctype_pointer
def EVT_SUBSCRIBE_CALLBACK(Action: win32more.Windows.Win32.System.EventLog.EVT_SUBSCRIBE_NOTIFY_ACTION, UserContext: VoidPtr, Event: win32more.Windows.Win32.System.EventLog.EVT_HANDLE) -> UInt32: ...
EVT_SUBSCRIBE_FLAGS = UInt32
EvtSubscribeToFutureEvents: win32more.Windows.Win32.System.EventLog.EVT_SUBSCRIBE_FLAGS = 1
EvtSubscribeStartAtOldestRecord: win32more.Windows.Win32.System.EventLog.EVT_SUBSCRIBE_FLAGS = 2
EvtSubscribeStartAfterBookmark: win32more.Windows.Win32.System.EventLog.EVT_SUBSCRIBE_FLAGS = 3
EvtSubscribeOriginMask: win32more.Windows.Win32.System.EventLog.EVT_SUBSCRIBE_FLAGS = 3
EvtSubscribeTolerateQueryErrors: win32more.Windows.Win32.System.EventLog.EVT_SUBSCRIBE_FLAGS = 4096
EvtSubscribeStrict: win32more.Windows.Win32.System.EventLog.EVT_SUBSCRIBE_FLAGS = 65536
EVT_SUBSCRIBE_NOTIFY_ACTION = Int32
EvtSubscribeActionError: win32more.Windows.Win32.System.EventLog.EVT_SUBSCRIBE_NOTIFY_ACTION = 0
EvtSubscribeActionDeliver: win32more.Windows.Win32.System.EventLog.EVT_SUBSCRIBE_NOTIFY_ACTION = 1
EVT_SYSTEM_PROPERTY_ID = Int32
EvtSystemProviderName: win32more.Windows.Win32.System.EventLog.EVT_SYSTEM_PROPERTY_ID = 0
EvtSystemProviderGuid: win32more.Windows.Win32.System.EventLog.EVT_SYSTEM_PROPERTY_ID = 1
EvtSystemEventID: win32more.Windows.Win32.System.EventLog.EVT_SYSTEM_PROPERTY_ID = 2
EvtSystemQualifiers: win32more.Windows.Win32.System.EventLog.EVT_SYSTEM_PROPERTY_ID = 3
EvtSystemLevel: win32more.Windows.Win32.System.EventLog.EVT_SYSTEM_PROPERTY_ID = 4
EvtSystemTask: win32more.Windows.Win32.System.EventLog.EVT_SYSTEM_PROPERTY_ID = 5
EvtSystemOpcode: win32more.Windows.Win32.System.EventLog.EVT_SYSTEM_PROPERTY_ID = 6
EvtSystemKeywords: win32more.Windows.Win32.System.EventLog.EVT_SYSTEM_PROPERTY_ID = 7
EvtSystemTimeCreated: win32more.Windows.Win32.System.EventLog.EVT_SYSTEM_PROPERTY_ID = 8
EvtSystemEventRecordId: win32more.Windows.Win32.System.EventLog.EVT_SYSTEM_PROPERTY_ID = 9
EvtSystemActivityID: win32more.Windows.Win32.System.EventLog.EVT_SYSTEM_PROPERTY_ID = 10
EvtSystemRelatedActivityID: win32more.Windows.Win32.System.EventLog.EVT_SYSTEM_PROPERTY_ID = 11
EvtSystemProcessID: win32more.Windows.Win32.System.EventLog.EVT_SYSTEM_PROPERTY_ID = 12
EvtSystemThreadID: win32more.Windows.Win32.System.EventLog.EVT_SYSTEM_PROPERTY_ID = 13
EvtSystemChannel: win32more.Windows.Win32.System.EventLog.EVT_SYSTEM_PROPERTY_ID = 14
EvtSystemComputer: win32more.Windows.Win32.System.EventLog.EVT_SYSTEM_PROPERTY_ID = 15
EvtSystemUserID: win32more.Windows.Win32.System.EventLog.EVT_SYSTEM_PROPERTY_ID = 16
EvtSystemVersion: win32more.Windows.Win32.System.EventLog.EVT_SYSTEM_PROPERTY_ID = 17
EvtSystemPropertyIdEND: win32more.Windows.Win32.System.EventLog.EVT_SYSTEM_PROPERTY_ID = 18
class EVT_VARIANT(Structure):
    Anonymous: _Anonymous_e__Union
    Count: UInt32
    Type: UInt32
    class _Anonymous_e__Union(Union):
        BooleanVal: win32more.Windows.Win32.Foundation.BOOL
        SByteVal: SByte
        Int16Val: Int16
        Int32Val: Int32
        Int64Val: Int64
        ByteVal: Byte
        UInt16Val: UInt16
        UInt32Val: UInt32
        UInt64Val: UInt64
        SingleVal: Single
        DoubleVal: Double
        FileTimeVal: UInt64
        SysTimeVal: POINTER(win32more.Windows.Win32.Foundation.SYSTEMTIME)
        GuidVal: POINTER(Guid)
        StringVal: win32more.Windows.Win32.Foundation.PWSTR
        AnsiStringVal: win32more.Windows.Win32.Foundation.PSTR
        BinaryVal: POINTER(Byte)
        SidVal: win32more.Windows.Win32.Security.PSID
        SizeTVal: UIntPtr
        BooleanArr: POINTER(win32more.Windows.Win32.Foundation.BOOL)
        SByteArr: POINTER(SByte)
        Int16Arr: POINTER(Int16)
        Int32Arr: POINTER(Int32)
        Int64Arr: POINTER(Int64)
        ByteArr: POINTER(Byte)
        UInt16Arr: POINTER(UInt16)
        UInt32Arr: POINTER(UInt32)
        UInt64Arr: POINTER(UInt64)
        SingleArr: POINTER(Single)
        DoubleArr: POINTER(Double)
        FileTimeArr: POINTER(win32more.Windows.Win32.Foundation.FILETIME)
        SysTimeArr: POINTER(win32more.Windows.Win32.Foundation.SYSTEMTIME)
        GuidArr: POINTER(Guid)
        StringArr: POINTER(win32more.Windows.Win32.Foundation.PWSTR)
        AnsiStringArr: POINTER(win32more.Windows.Win32.Foundation.PSTR)
        SidArr: POINTER(win32more.Windows.Win32.Security.PSID)
        SizeTArr: POINTER(UIntPtr)
        EvtHandleVal: win32more.Windows.Win32.System.EventLog.EVT_HANDLE
        XmlVal: win32more.Windows.Win32.Foundation.PWSTR
        XmlValArr: POINTER(win32more.Windows.Win32.Foundation.PWSTR)
EVT_VARIANT_TYPE = Int32
EvtVarTypeNull: win32more.Windows.Win32.System.EventLog.EVT_VARIANT_TYPE = 0
EvtVarTypeString: win32more.Windows.Win32.System.EventLog.EVT_VARIANT_TYPE = 1
EvtVarTypeAnsiString: win32more.Windows.Win32.System.EventLog.EVT_VARIANT_TYPE = 2
EvtVarTypeSByte: win32more.Windows.Win32.System.EventLog.EVT_VARIANT_TYPE = 3
EvtVarTypeByte: win32more.Windows.Win32.System.EventLog.EVT_VARIANT_TYPE = 4
EvtVarTypeInt16: win32more.Windows.Win32.System.EventLog.EVT_VARIANT_TYPE = 5
EvtVarTypeUInt16: win32more.Windows.Win32.System.EventLog.EVT_VARIANT_TYPE = 6
EvtVarTypeInt32: win32more.Windows.Win32.System.EventLog.EVT_VARIANT_TYPE = 7
EvtVarTypeUInt32: win32more.Windows.Win32.System.EventLog.EVT_VARIANT_TYPE = 8
EvtVarTypeInt64: win32more.Windows.Win32.System.EventLog.EVT_VARIANT_TYPE = 9
EvtVarTypeUInt64: win32more.Windows.Win32.System.EventLog.EVT_VARIANT_TYPE = 10
EvtVarTypeSingle: win32more.Windows.Win32.System.EventLog.EVT_VARIANT_TYPE = 11
EvtVarTypeDouble: win32more.Windows.Win32.System.EventLog.EVT_VARIANT_TYPE = 12
EvtVarTypeBoolean: win32more.Windows.Win32.System.EventLog.EVT_VARIANT_TYPE = 13
EvtVarTypeBinary: win32more.Windows.Win32.System.EventLog.EVT_VARIANT_TYPE = 14
EvtVarTypeGuid: win32more.Windows.Win32.System.EventLog.EVT_VARIANT_TYPE = 15
EvtVarTypeSizeT: win32more.Windows.Win32.System.EventLog.EVT_VARIANT_TYPE = 16
EvtVarTypeFileTime: win32more.Windows.Win32.System.EventLog.EVT_VARIANT_TYPE = 17
EvtVarTypeSysTime: win32more.Windows.Win32.System.EventLog.EVT_VARIANT_TYPE = 18
EvtVarTypeSid: win32more.Windows.Win32.System.EventLog.EVT_VARIANT_TYPE = 19
EvtVarTypeHexInt32: win32more.Windows.Win32.System.EventLog.EVT_VARIANT_TYPE = 20
EvtVarTypeHexInt64: win32more.Windows.Win32.System.EventLog.EVT_VARIANT_TYPE = 21
EvtVarTypeEvtHandle: win32more.Windows.Win32.System.EventLog.EVT_VARIANT_TYPE = 32
EvtVarTypeEvtXml: win32more.Windows.Win32.System.EventLog.EVT_VARIANT_TYPE = 35
READ_EVENT_LOG_READ_FLAGS = UInt32
EVENTLOG_SEEK_READ: win32more.Windows.Win32.System.EventLog.READ_EVENT_LOG_READ_FLAGS = 2
EVENTLOG_SEQUENTIAL_READ: win32more.Windows.Win32.System.EventLog.READ_EVENT_LOG_READ_FLAGS = 1
REPORT_EVENT_TYPE = UInt16
EVENTLOG_SUCCESS: win32more.Windows.Win32.System.EventLog.REPORT_EVENT_TYPE = 0
EVENTLOG_AUDIT_FAILURE: win32more.Windows.Win32.System.EventLog.REPORT_EVENT_TYPE = 16
EVENTLOG_AUDIT_SUCCESS: win32more.Windows.Win32.System.EventLog.REPORT_EVENT_TYPE = 8
EVENTLOG_ERROR_TYPE: win32more.Windows.Win32.System.EventLog.REPORT_EVENT_TYPE = 1
EVENTLOG_INFORMATION_TYPE: win32more.Windows.Win32.System.EventLog.REPORT_EVENT_TYPE = 4
EVENTLOG_WARNING_TYPE: win32more.Windows.Win32.System.EventLog.REPORT_EVENT_TYPE = 2


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Graphics.Gdi
import win32more.Windows.Win32.System.Com
import win32more.Windows.Win32.System.Com.StructuredStorage
import win32more.Windows.Win32.UI.Ribbon
UI_ALL_COMMANDS: UInt32 = 0
UI_COLLECTION_INVALIDINDEX: UInt32 = 4294967295
LIBID_UIRibbon: Guid = Guid('{942f35c2-e83b-45ef-b085-ac295dd63d5b}')
class IUIApplication(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{d428903c-729a-491d-910d-682a08ff2522}')
    @commethod(3)
    def OnViewChanged(self, viewId: UInt32, typeID: win32more.Windows.Win32.UI.Ribbon.UI_VIEWTYPE, view: win32more.Windows.Win32.System.Com.IUnknown, verb: win32more.Windows.Win32.UI.Ribbon.UI_VIEWVERB, uReasonCode: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def OnCreateUICommand(self, commandId: UInt32, typeID: win32more.Windows.Win32.UI.Ribbon.UI_COMMANDTYPE, commandHandler: POINTER(win32more.Windows.Win32.UI.Ribbon.IUICommandHandler)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def OnDestroyUICommand(self, commandId: UInt32, typeID: win32more.Windows.Win32.UI.Ribbon.UI_COMMANDTYPE, commandHandler: win32more.Windows.Win32.UI.Ribbon.IUICommandHandler) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUICollection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{df4f45bf-6f9d-4dd7-9d68-d8f9cd18c4db}')
    @commethod(3)
    def GetCount(self, count: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetItem(self, index: UInt32, item: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Add(self, item: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Insert(self, index: UInt32, item: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def RemoveAt(self, index: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def Replace(self, indexReplaced: UInt32, itemReplaceWith: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def Clear(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUICollectionChangedEvent(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{6502ae91-a14d-44b5-bbd0-62aacc581d52}')
    @commethod(3)
    def OnChanged(self, action: win32more.Windows.Win32.UI.Ribbon.UI_COLLECTIONCHANGE, oldIndex: UInt32, oldItem: win32more.Windows.Win32.System.Com.IUnknown, newIndex: UInt32, newItem: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUICommandHandler(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{75ae0a2d-dc03-4c9f-8883-069660d0beb6}')
    @commethod(3)
    def Execute(self, commandId: UInt32, verb: win32more.Windows.Win32.UI.Ribbon.UI_EXECUTIONVERB, key: POINTER(win32more.Windows.Win32.Foundation.PROPERTYKEY), currentValue: POINTER(win32more.Windows.Win32.System.Com.StructuredStorage.PROPVARIANT), commandExecutionProperties: win32more.Windows.Win32.UI.Ribbon.IUISimplePropertySet) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def UpdateProperty(self, commandId: UInt32, key: POINTER(win32more.Windows.Win32.Foundation.PROPERTYKEY), currentValue: POINTER(win32more.Windows.Win32.System.Com.StructuredStorage.PROPVARIANT), newValue: POINTER(win32more.Windows.Win32.System.Com.StructuredStorage.PROPVARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUIContextualUI(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{eea11f37-7c46-437c-8e55-b52122b29293}')
    @commethod(3)
    def ShowAtLocation(self, x: Int32, y: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUIEventLogger(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{ec3e1034-dbf4-41a1-95d5-03e0f1026e05}')
    @commethod(3)
    def OnUIEvent(self, pEventParams: POINTER(win32more.Windows.Win32.UI.Ribbon.UI_EVENTPARAMS)) -> Void: ...
class IUIEventingManager(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{3be6ea7f-9a9b-4198-9368-9b0f923bd534}')
    @commethod(3)
    def SetEventLogger(self, eventLogger: win32more.Windows.Win32.UI.Ribbon.IUIEventLogger) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUIFramework(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{f4f0385d-6872-43a8-ad09-4c339cb3f5c5}')
    @commethod(3)
    def Initialize(self, frameWnd: win32more.Windows.Win32.Foundation.HWND, application: win32more.Windows.Win32.UI.Ribbon.IUIApplication) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Destroy(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def LoadUI(self, instance: win32more.Windows.Win32.Foundation.HINSTANCE, resourceName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetView(self, viewId: UInt32, riid: POINTER(Guid), ppv: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetUICommandProperty(self, commandId: UInt32, key: POINTER(win32more.Windows.Win32.Foundation.PROPERTYKEY), value: POINTER(win32more.Windows.Win32.System.Com.StructuredStorage.PROPVARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def SetUICommandProperty(self, commandId: UInt32, key: POINTER(win32more.Windows.Win32.Foundation.PROPERTYKEY), value: POINTER(win32more.Windows.Win32.System.Com.StructuredStorage.PROPVARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def InvalidateUICommand(self, commandId: UInt32, flags: win32more.Windows.Win32.UI.Ribbon.UI_INVALIDATIONS, key: POINTER(win32more.Windows.Win32.Foundation.PROPERTYKEY)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def FlushPendingInvalidations(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def SetModes(self, iModes: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUIImage(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{23c8c838-4de6-436b-ab01-5554bb7c30dd}')
    @commethod(3)
    def GetBitmap(self, bitmap: POINTER(win32more.Windows.Win32.Graphics.Gdi.HBITMAP)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUIImageFromBitmap(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{18aba7f3-4c1c-4ba2-bf6c-f5c3326fa816}')
    @commethod(3)
    def CreateImage(self, bitmap: win32more.Windows.Win32.Graphics.Gdi.HBITMAP, options: win32more.Windows.Win32.UI.Ribbon.UI_OWNERSHIP, image: POINTER(win32more.Windows.Win32.UI.Ribbon.IUIImage)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUIRibbon(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{803982ab-370a-4f7e-a9e7-8784036a6e26}')
    @commethod(3)
    def GetHeight(self, cy: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def LoadSettingsFromStream(self, pStream: win32more.Windows.Win32.System.Com.IStream) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SaveSettingsToStream(self, pStream: win32more.Windows.Win32.System.Com.IStream) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUISimplePropertySet(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{c205bb48-5b1c-4219-a106-15bd0a5f24e2}')
    @commethod(3)
    def GetValue(self, key: POINTER(win32more.Windows.Win32.Foundation.PROPERTYKEY), value: POINTER(win32more.Windows.Win32.System.Com.StructuredStorage.PROPVARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
UIRibbonFramework = Guid('{926749fa-2615-4987-8845-c33e65f2b957}')
UIRibbonImageFromBitmapFactory = Guid('{0f7434b6-59b6-4250-999e-d168d6ae4293}')
UI_COLLECTIONCHANGE = Int32
UI_COLLECTIONCHANGE_INSERT: win32more.Windows.Win32.UI.Ribbon.UI_COLLECTIONCHANGE = 0
UI_COLLECTIONCHANGE_REMOVE: win32more.Windows.Win32.UI.Ribbon.UI_COLLECTIONCHANGE = 1
UI_COLLECTIONCHANGE_REPLACE: win32more.Windows.Win32.UI.Ribbon.UI_COLLECTIONCHANGE = 2
UI_COLLECTIONCHANGE_RESET: win32more.Windows.Win32.UI.Ribbon.UI_COLLECTIONCHANGE = 3
UI_COMMANDTYPE = Int32
UI_COMMANDTYPE_UNKNOWN: win32more.Windows.Win32.UI.Ribbon.UI_COMMANDTYPE = 0
UI_COMMANDTYPE_GROUP: win32more.Windows.Win32.UI.Ribbon.UI_COMMANDTYPE = 1
UI_COMMANDTYPE_ACTION: win32more.Windows.Win32.UI.Ribbon.UI_COMMANDTYPE = 2
UI_COMMANDTYPE_ANCHOR: win32more.Windows.Win32.UI.Ribbon.UI_COMMANDTYPE = 3
UI_COMMANDTYPE_CONTEXT: win32more.Windows.Win32.UI.Ribbon.UI_COMMANDTYPE = 4
UI_COMMANDTYPE_COLLECTION: win32more.Windows.Win32.UI.Ribbon.UI_COMMANDTYPE = 5
UI_COMMANDTYPE_COMMANDCOLLECTION: win32more.Windows.Win32.UI.Ribbon.UI_COMMANDTYPE = 6
UI_COMMANDTYPE_DECIMAL: win32more.Windows.Win32.UI.Ribbon.UI_COMMANDTYPE = 7
UI_COMMANDTYPE_BOOLEAN: win32more.Windows.Win32.UI.Ribbon.UI_COMMANDTYPE = 8
UI_COMMANDTYPE_FONT: win32more.Windows.Win32.UI.Ribbon.UI_COMMANDTYPE = 9
UI_COMMANDTYPE_RECENTITEMS: win32more.Windows.Win32.UI.Ribbon.UI_COMMANDTYPE = 10
UI_COMMANDTYPE_COLORANCHOR: win32more.Windows.Win32.UI.Ribbon.UI_COMMANDTYPE = 11
UI_COMMANDTYPE_COLORCOLLECTION: win32more.Windows.Win32.UI.Ribbon.UI_COMMANDTYPE = 12
UI_CONTEXTAVAILABILITY = Int32
UI_CONTEXTAVAILABILITY_NOTAVAILABLE: win32more.Windows.Win32.UI.Ribbon.UI_CONTEXTAVAILABILITY = 0
UI_CONTEXTAVAILABILITY_AVAILABLE: win32more.Windows.Win32.UI.Ribbon.UI_CONTEXTAVAILABILITY = 1
UI_CONTEXTAVAILABILITY_ACTIVE: win32more.Windows.Win32.UI.Ribbon.UI_CONTEXTAVAILABILITY = 2
UI_CONTROLDOCK = Int32
UI_CONTROLDOCK_TOP: win32more.Windows.Win32.UI.Ribbon.UI_CONTROLDOCK = 1
UI_CONTROLDOCK_BOTTOM: win32more.Windows.Win32.UI.Ribbon.UI_CONTROLDOCK = 3
UI_EVENTLOCATION = Int32
UI_EVENTLOCATION_Ribbon: win32more.Windows.Win32.UI.Ribbon.UI_EVENTLOCATION = 0
UI_EVENTLOCATION_QAT: win32more.Windows.Win32.UI.Ribbon.UI_EVENTLOCATION = 1
UI_EVENTLOCATION_ApplicationMenu: win32more.Windows.Win32.UI.Ribbon.UI_EVENTLOCATION = 2
UI_EVENTLOCATION_ContextPopup: win32more.Windows.Win32.UI.Ribbon.UI_EVENTLOCATION = 3
class UI_EVENTPARAMS(Structure):
    EventType: win32more.Windows.Win32.UI.Ribbon.UI_EVENTTYPE
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Modes: Int32
        Params: win32more.Windows.Win32.UI.Ribbon.UI_EVENTPARAMS_COMMAND
class UI_EVENTPARAMS_COMMAND(Structure):
    CommandID: UInt32
    CommandName: win32more.Windows.Win32.Foundation.PWSTR
    ParentCommandID: UInt32
    ParentCommandName: win32more.Windows.Win32.Foundation.PWSTR
    SelectionIndex: UInt32
    Location: win32more.Windows.Win32.UI.Ribbon.UI_EVENTLOCATION
UI_EVENTTYPE = Int32
UI_EVENTTYPE_ApplicationMenuOpened: win32more.Windows.Win32.UI.Ribbon.UI_EVENTTYPE = 0
UI_EVENTTYPE_RibbonMinimized: win32more.Windows.Win32.UI.Ribbon.UI_EVENTTYPE = 1
UI_EVENTTYPE_RibbonExpanded: win32more.Windows.Win32.UI.Ribbon.UI_EVENTTYPE = 2
UI_EVENTTYPE_ApplicationModeSwitched: win32more.Windows.Win32.UI.Ribbon.UI_EVENTTYPE = 3
UI_EVENTTYPE_TabActivated: win32more.Windows.Win32.UI.Ribbon.UI_EVENTTYPE = 4
UI_EVENTTYPE_MenuOpened: win32more.Windows.Win32.UI.Ribbon.UI_EVENTTYPE = 5
UI_EVENTTYPE_CommandExecuted: win32more.Windows.Win32.UI.Ribbon.UI_EVENTTYPE = 6
UI_EVENTTYPE_TooltipShown: win32more.Windows.Win32.UI.Ribbon.UI_EVENTTYPE = 7
UI_EXECUTIONVERB = Int32
UI_EXECUTIONVERB_EXECUTE: win32more.Windows.Win32.UI.Ribbon.UI_EXECUTIONVERB = 0
UI_EXECUTIONVERB_PREVIEW: win32more.Windows.Win32.UI.Ribbon.UI_EXECUTIONVERB = 1
UI_EXECUTIONVERB_CANCELPREVIEW: win32more.Windows.Win32.UI.Ribbon.UI_EXECUTIONVERB = 2
UI_FONTDELTASIZE = Int32
UI_FONTDELTASIZE_GROW: win32more.Windows.Win32.UI.Ribbon.UI_FONTDELTASIZE = 0
UI_FONTDELTASIZE_SHRINK: win32more.Windows.Win32.UI.Ribbon.UI_FONTDELTASIZE = 1
UI_FONTPROPERTIES = Int32
UI_FONTPROPERTIES_NOTAVAILABLE: win32more.Windows.Win32.UI.Ribbon.UI_FONTPROPERTIES = 0
UI_FONTPROPERTIES_NOTSET: win32more.Windows.Win32.UI.Ribbon.UI_FONTPROPERTIES = 1
UI_FONTPROPERTIES_SET: win32more.Windows.Win32.UI.Ribbon.UI_FONTPROPERTIES = 2
UI_FONTUNDERLINE = Int32
UI_FONTUNDERLINE_NOTAVAILABLE: win32more.Windows.Win32.UI.Ribbon.UI_FONTUNDERLINE = 0
UI_FONTUNDERLINE_NOTSET: win32more.Windows.Win32.UI.Ribbon.UI_FONTUNDERLINE = 1
UI_FONTUNDERLINE_SET: win32more.Windows.Win32.UI.Ribbon.UI_FONTUNDERLINE = 2
UI_FONTVERTICALPOSITION = Int32
UI_FONTVERTICALPOSITION_NOTAVAILABLE: win32more.Windows.Win32.UI.Ribbon.UI_FONTVERTICALPOSITION = 0
UI_FONTVERTICALPOSITION_NOTSET: win32more.Windows.Win32.UI.Ribbon.UI_FONTVERTICALPOSITION = 1
UI_FONTVERTICALPOSITION_SUPERSCRIPT: win32more.Windows.Win32.UI.Ribbon.UI_FONTVERTICALPOSITION = 2
UI_FONTVERTICALPOSITION_SUBSCRIPT: win32more.Windows.Win32.UI.Ribbon.UI_FONTVERTICALPOSITION = 3
UI_INVALIDATIONS = Int32
UI_INVALIDATIONS_STATE: win32more.Windows.Win32.UI.Ribbon.UI_INVALIDATIONS = 1
UI_INVALIDATIONS_VALUE: win32more.Windows.Win32.UI.Ribbon.UI_INVALIDATIONS = 2
UI_INVALIDATIONS_PROPERTY: win32more.Windows.Win32.UI.Ribbon.UI_INVALIDATIONS = 4
UI_INVALIDATIONS_ALLPROPERTIES: win32more.Windows.Win32.UI.Ribbon.UI_INVALIDATIONS = 8
UI_OWNERSHIP = Int32
UI_OWNERSHIP_TRANSFER: win32more.Windows.Win32.UI.Ribbon.UI_OWNERSHIP = 0
UI_OWNERSHIP_COPY: win32more.Windows.Win32.UI.Ribbon.UI_OWNERSHIP = 1
UI_SWATCHCOLORMODE = Int32
UI_SWATCHCOLORMODE_NORMAL: win32more.Windows.Win32.UI.Ribbon.UI_SWATCHCOLORMODE = 0
UI_SWATCHCOLORMODE_MONOCHROME: win32more.Windows.Win32.UI.Ribbon.UI_SWATCHCOLORMODE = 1
UI_SWATCHCOLORTYPE = Int32
UI_SWATCHCOLORTYPE_NOCOLOR: win32more.Windows.Win32.UI.Ribbon.UI_SWATCHCOLORTYPE = 0
UI_SWATCHCOLORTYPE_AUTOMATIC: win32more.Windows.Win32.UI.Ribbon.UI_SWATCHCOLORTYPE = 1
UI_SWATCHCOLORTYPE_RGB: win32more.Windows.Win32.UI.Ribbon.UI_SWATCHCOLORTYPE = 2
UI_VIEWTYPE = Int32
UI_VIEWTYPE_RIBBON: win32more.Windows.Win32.UI.Ribbon.UI_VIEWTYPE = 1
UI_VIEWVERB = Int32
UI_VIEWVERB_CREATE: win32more.Windows.Win32.UI.Ribbon.UI_VIEWVERB = 0
UI_VIEWVERB_DESTROY: win32more.Windows.Win32.UI.Ribbon.UI_VIEWVERB = 1
UI_VIEWVERB_SIZE: win32more.Windows.Win32.UI.Ribbon.UI_VIEWVERB = 2
UI_VIEWVERB_ERROR: win32more.Windows.Win32.UI.Ribbon.UI_VIEWVERB = 3


make_ready(__name__)
